==> v0.1.50-snapshot.tar.gz: beteran-protobuf-rust/src/ss/identity.rs <==
const SUBJECT: &str = "bet.beteran.ss.identity";
const EVENT_SUBJECT: &str = "bet.beteran.ss_event.identity";

pub const SUBJECT_CHECK_USERNAME_FOR_DUPLICATION: &str =
  const_format::concatcp!(SUBJECT, ".CheckUsernameForDuplication");
pub const SUBJECT_CHECK_NICKNAME_FOR_DUPLICATION: &str =
  const_format::concatcp!(SUBJECT, ".CheckNicknameForDuplication");
pub const SUBJECT_CAPTCHA: &str = const_format::concatcp!(SUBJECT, ".Captcha");
pub const SUBJECT_SIGNIN: &str = const_format::concatcp!(SUBJECT, ".Signin");

pub const EVENT_SUBJECT_SIGNIN: &str = const_format::concatcp!(EVENT_SUBJECT, ".AfterSignin");

/// subject = bet.beteran.ss.identity.CheckUsernameForDuplication;
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CheckUsernameForDuplicationRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<check_username_for_duplication_request::Request>,
}
/// Nested message and enum types in `CheckUsernameForDuplicationRequest`.
pub mod check_username_for_duplication_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub username: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CheckUsernameForDuplicationResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<check_username_for_duplication_response::Result>,
}
/// Nested message and enum types in `CheckUsernameForDuplicationResponse`.
pub mod check_username_for_duplication_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(bool, tag = "1")]
    pub duplicated: bool,
  }
}
/// subject = bet.beteran.ss.identity.CheckNicknameForDuplication;
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CheckNicknameForDuplicationRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<check_nickname_for_duplication_request::Request>,
}
/// Nested message and enum types in `CheckNicknameForDuplicationRequest`.
pub mod check_nickname_for_duplication_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub nickname: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CheckNicknameForDuplicationResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<check_nickname_for_duplication_response::Result>,
}
/// Nested message and enum types in `CheckNicknameForDuplicationResponse`.
pub mod check_nickname_for_duplication_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(bool, tag = "1")]
    pub duplicated: bool,
  }
}
/// subject = bet.beteran.ss.identity.Captcha
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CaptchaRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<captcha_request::Request>,
}
/// Nested message and enum types in `CaptchaRequest`.
pub mod captcha_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {}
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CaptchaResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<captcha_response::Result>,
}
/// Nested message and enum types in `CaptchaResponse`.
pub mod captcha_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(string, tag = "1")]
    pub security_code_hash: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub image: ::prost::alloc::string::String,
  }
}
/// subject = bet.beteran.ss.identity.Signin
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct SigninRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<signin_request::Request>,
}
/// Nested message and enum types in `SigninRequest`.
pub mod signin_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub security_code_hash: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub security_code: ::prost::alloc::string::String,
    #[prost(string, tag = "3")]
    pub username: ::prost::alloc::string::String,
    #[prost(string, tag = "4")]
    pub password: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct SigninResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<signin_response::Result>,
}
/// Nested message and enum types in `SigninResponse`.
pub mod signin_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(string, tag = "1")]
    pub access_token: ::prost::alloc::string::String,
  }
}
/// subject = bet.beteran.ss_event.identity.AfterSignin
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct AfterSigninEvent {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub event: ::core::option::Option<after_signin_event::Event>,
}
/// Nested message and enum types in `AfterSigninEvent`.
pub mod after_signin_event {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Event {
    #[prost(message, optional, tag = "1")]
    pub member: ::core::option::Option<crate::models::member::Member>,
  }
}

==> v0.1.53-snapshot.tar.gz: beteran-protobuf-rust/src/ss/identity.rs <==
const SUBJECT: &str = "bet.beteran.ss.identity";
const EVENT_SUBJECT: &str = "bet.beteran.ss_event.identity";

pub const SUBJECT_CHECK_USERNAME_FOR_DUPLICATION: &str =
  const_format::concatcp!(SUBJECT, ".CheckUsernameForDuplication");
pub const SUBJECT_CHECK_NICKNAME_FOR_DUPLICATION: &str =
  const_format::concatcp!(SUBJECT, ".CheckNicknameForDuplication");
pub const SUBJECT_CAPTCHA: &str = const_format::concatcp!(SUBJECT, ".Captcha");
pub const SUBJECT_SIGNIN: &str = const_format::concatcp!(SUBJECT, ".Signin");

pub const EVENT_SUBJECT_AFTER_SIGNIN: &str = const_format::concatcp!(EVENT_SUBJECT, ".AfterSignin");

/// subject = bet.beteran.ss.identity.CheckUsernameForDuplication;
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CheckUsernameForDuplicationRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<check_username_for_duplication_request::Request>,
}
/// Nested message and enum types in `CheckUsernameForDuplicationRequest`.
pub mod check_username_for_duplication_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub username: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CheckUsernameForDuplicationResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<check_username_for_duplication_response::Result>,
}
/// Nested message and enum types in `CheckUsernameForDuplicationResponse`.
pub mod check_username_for_duplication_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(bool, tag = "1")]
    pub duplicated: bool,
  }
}
/// subject = bet.beteran.ss.identity.CheckNicknameForDuplication;
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CheckNicknameForDuplicationRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<check_nickname_for_duplication_request::Request>,
}
/// Nested message and enum types in `CheckNicknameForDuplicationRequest`.
pub mod check_nickname_for_duplication_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub nickname: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CheckNicknameForDuplicationResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<check_nickname_for_duplication_response::Result>,
}
/// Nested message and enum types in `CheckNicknameForDuplicationResponse`.
pub mod check_nickname_for_duplication_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(bool, tag = "1")]
    pub duplicated: bool,
  }
}
/// subject = bet.beteran.ss.identity.Captcha
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CaptchaRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<captcha_request::Request>,
}
/// Nested message and enum types in `CaptchaRequest`.
pub mod captcha_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {}
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct CaptchaResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<captcha_response::Result>,
}
/// Nested message and enum types in `CaptchaResponse`.
pub mod captcha_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(string, tag = "1")]
    pub security_code_hash: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub image: ::prost::alloc::string::String,
  }
}
/// subject = bet.beteran.ss.identity.Signin
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct SigninRequest {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub request: ::core::option::Option<signin_request::Request>,
}
/// Nested message and enum types in `SigninRequest`.
pub mod signin_request {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Request {
    #[prost(string, tag = "1")]
    pub security_code_hash: ::prost::alloc::string::String,
    #[prost(string, tag = "2")]
    pub security_code: ::prost::alloc::string::String,
    #[prost(string, tag = "3")]
    pub username: ::prost::alloc::string::String,
    #[prost(string, tag = "4")]
    pub password: ::prost::alloc::string::String,
  }
}
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct SigninResponse {
  #[prost(message, optional, tag = "1")]
  pub error: ::core::option::Option<crate::protobuf::rpc::Error>,
  #[prost(message, optional, tag = "2")]
  pub result: ::core::option::Option<signin_response::Result>,
}
/// Nested message and enum types in `SigninResponse`.
pub mod signin_response {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Result {
    #[prost(string, tag = "1")]
    pub access_token: ::prost::alloc::string::String,
  }
}
/// subject = bet.beteran.ss_event.identity.AfterSignin
#[derive(Clone, PartialEq, ::prost::Message)]
pub struct AfterSigninEvent {
  #[prost(message, optional, tag = "1")]
  pub client: ::core::option::Option<crate::models::core::network::Client>,
  #[prost(message, optional, tag = "2")]
  pub event: ::core::option::Option<after_signin_event::Event>,
}
/// Nested message and enum types in `AfterSigninEvent`.
pub mod after_signin_event {
  #[derive(Clone, PartialEq, ::prost::Message)]
  pub struct Event {
    #[prost(message, optional, tag = "1")]
    pub member: ::core::option::Option<crate::models::member::Member>,
  }
}
